@@ -61,6 +61,7 @@ class EdgeFunction(
         filesystem: typing.Optional[aws_cdk.aws_lambda.FileSystem] = None,
         function_name: typing.Optional[builtins.str] = None,
         initial_policy: typing.Optional[typing.Sequence[aws_cdk.aws_iam.PolicyStatement]] = None,
+        insights_version: typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion] = None,
         layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
         log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
         log_retention_retry_options: typing.Optional[aws_cdk.aws_lambda.LogRetentionRetryOptions] = None,
@@ -101,6 +102,7 @@ class EdgeFunction(
         :param filesystem: The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
         :param initial_policy: Initial policy statements to add to the created Lambda Role. You can call ``addToRolePolicy`` to the created lambda to add statements post creation. Default: - No policy statements are added to the created Lambda role.
+        :param insights_version: Specify the version of CloudWatch Lambda insights to use for monitoring. Default: - No Lambda Insights
         :param layers: A list of layers to add to the function's execution environment. You can configure your Lambda function to pull in additional code during initialization in the form of layers. Layers are packages of libraries or other dependencies that can be used by multiple functions. Default: - No layers.
         :param log_retention: The number of days log events are kept in CloudWatch Logs. When updating this property, unsetting it doesn't remove the log retention policy. To remove the retention policy, set the value to ``INFINITE``. Default: logs.RetentionDays.INFINITE
         :param log_retention_retry_options: When log retention is specified, a custom resource attempts to create the CloudWatch log group. These options control the retry policy when interacting with CloudWatch APIs. Default: - Default AWS SDK retry options.
@@ -139,6 +141,7 @@ class EdgeFunction(
             filesystem=filesystem,
             function_name=function_name,
             initial_policy=initial_policy,
+            insights_version=insights_version,
             layers=layers,
             log_retention=log_retention,
             log_retention_retry_options=log_retention_retry_options,
@@ -672,6 +675,7 @@ class EdgeFunction(
         "filesystem": "filesystem",
         "function_name": "functionName",
         "initial_policy": "initialPolicy",
+        "insights_version": "insightsVersion",
         "layers": "layers",
         "log_retention": "logRetention",
         "log_retention_retry_options": "logRetentionRetryOptions",
@@ -714,6 +718,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         filesystem: typing.Optional[aws_cdk.aws_lambda.FileSystem] = None,
         function_name: typing.Optional[builtins.str] = None,
         initial_policy: typing.Optional[typing.Sequence[aws_cdk.aws_iam.PolicyStatement]] = None,
+        insights_version: typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion] = None,
         layers: typing.Optional[typing.Sequence[aws_cdk.aws_lambda.ILayerVersion]] = None,
         log_retention: typing.Optional[aws_cdk.aws_logs.RetentionDays] = None,
         log_retention_retry_options: typing.Optional[aws_cdk.aws_lambda.LogRetentionRetryOptions] = None,
@@ -753,6 +758,7 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         :param filesystem: The filesystem configuration for the lambda function. Default: - will not mount any filesystem
         :param function_name: A name for the function. Default: - AWS CloudFormation generates a unique physical ID and uses that ID for the function's name. For more information, see Name Type.
         :param initial_policy: Initial policy statements to add to the created Lambda Role. You can call ``addToRolePolicy`` to the created lambda to add statements post creation. Default: - No policy statements are added to the created Lambda role.
+        :param insights_version: Specify the version of CloudWatch Lambda insights to use for monitoring. Default: - No Lambda Insights
         :param layers: A list of layers to add to the function's execution environment. You can configure your Lambda function to pull in additional code during initialization in the form of layers. Layers are packages of libraries or other dependencies that can be used by multiple functions. Default: - No layers.
         :param log_retention: The number of days log events are kept in CloudWatch Logs. When updating this property, unsetting it doesn't remove the log retention policy. To remove the retention policy, set the value to ``INFINITE``. Default: logs.RetentionDays.INFINITE
         :param log_retention_retry_options: When log retention is specified, a custom resource attempts to create the CloudWatch log group. These options control the retry policy when interacting with CloudWatch APIs. Default: - Default AWS SDK retry options.
@@ -818,6 +824,8 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
             self._values["function_name"] = function_name
         if initial_policy is not None:
             self._values["initial_policy"] = initial_policy
+        if insights_version is not None:
+            self._values["insights_version"] = insights_version
         if layers is not None:
             self._values["layers"] = layers
         if log_retention is not None:
@@ -1039,6 +1047,19 @@ class EdgeFunctionProps(aws_cdk.aws_lambda.FunctionProps):
         result = self._values.get("initial_policy")
         return typing.cast(typing.Optional[typing.List[aws_cdk.aws_iam.PolicyStatement]], result)
 
+    @builtins.property
+    def insights_version(
+        self,
+    ) -> typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion]:
+        '''Specify the version of CloudWatch Lambda insights to use for monitoring.
+
+        :default: - No Lambda Insights
+
+        :see: https://docs.aws.amazon.com/AmazonCloudWatch/latest/monitoring/Lambda-Insights.html
+        '''
+        result = self._values.get("insights_version")
+        return typing.cast(typing.Optional[aws_cdk.aws_lambda.LambdaInsightsVersion], result)
+
     @builtins.property
     def layers(self) -> typing.Optional[typing.List[aws_cdk.aws_lambda.ILayerVersion]]:
         '''A list of layers to add to the function's execution environment.
